cubicweb.goa.js — CubicWeb 3.11.0

### Navigation

- index
- modules |
- CubicWeb 3.11.0 »

# cubicweb.goa.js

functions specific to cubicweb on google appengine

> organization: | Logilab
> copyright: | 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
> contact: | http://www.logilab.fr/ – mailto:contact@logilab.fr

`cubicweb.goa.js.` `rql_for_eid`(eid)

overrides rql_for_eid function from htmlhelpers.hs

### Navigation

- index
- modules |
- CubicWeb 3.11.0 »